/***********************************************************************
 * File: numeral.h
 * 	(Extracted from
 *	   "$Id: numeral.h,v 1.6 2006/08/20 10:12:47 maoyam Exp maoyam $")
 *
 * Abstracts:
 *  This C header defines `numeral()' API prototyping.
 *
 * Copyright (C) 2005-2006 Maoyam Tokyo, Japan (mailto:maoyam@mail.goo.ne.jp)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
 **********************************************************************/

#ifndef _NUMERAL_H_ /* { */
#define _NUMERAL_H_

#include <unistd.h>
#include <stddef.h>
#include <stdlib.h>
#include <stdio.h>
#include <ctype.h>
#include <string.h>


/*
 * This API translates a numeral string to American's notation.
 *
 * arguments:
 *	src is pointing to the numeral string.
 *	dst is pointing to output string area.
 *	sz indicates the size of `dst' pointing to area.
 *	style indicates the numeral representation style for English
 *	or American.
 *
 * returns:
 *	NUMERAL_NORMAL_END (= 0)	: normal end
 *	NUMERAL_ILLEGAL_ARGS (= 1)	: illegal arguments
 *	NUMERAL_BUFFER_OVERFLOW (= 2)	: buffer overflow
 */
typedef enum numeral_repre_style_t {
	  NUMERAL_STYLE_ENGLISH	 /* for English */
	, NUMERAL_STYLE_AMERICAN /* for American */
} NUMERAL_REPRE_STYLE_t;

extern int numeral(char *src
		, char *dst
		, size_t sz
		, NUMERAL_REPRE_STYLE_t style
		);
#define NUMERAL_NORMAL_END	0
#define NUMERAL_ILLEGAL_ARGS	1
#define NUMERAL_BUFFER_OVERFLOW	2

/*
 * This API translates a "real" numeral string to English or American
 * notation.
 *
 * arguments:
 *	src is pointing to the "real" numeral string.
 *	dst is pointing to output string area.
 *	sz indicates the size of `dst' pointing to area.
 *	style indicates the numeral representation style for English
 *	or American.
 *
 * returns:
 *	NUMERAL_NORMAL_END (= 0)	: normal end
 *	NUMERAL_ILLEGAL_ARGS (= 1)	: illegal arguments
 *	NUMERAL_BUFFER_OVERFLOW (= 2)	: buffer overflow
 */
extern int real_numeral(char *src
			, char *dst
			, size_t sz
			, NUMERAL_REPRE_STYLE_t style
			);

#endif /* } !defined(_NUMERAL_H_) */
